@@ -1,34 +1,29 @@
 class Token:
     """Representation of a single Token"""
 
-    def __init__(self, _type, lexeme, literal=None):
-        self.type = _type
+    def __init__(self, kind, lexeme, literal=None):
+        self.kind = kind
         self.lexeme = lexeme
         self.literal = literal
 
-    def __hash__(self):
-        return hash((self.type, self.lexeme, self.literal))
-
     def __eq__(self, other):
-        if not isinstance(other, type(self)):
-            return False
         return (
-            self.type == other.type
+            self.kind == other.kind
             and self.lexeme == other.lexeme
             and self.literal == other.literal
         )
 
-    def __repr__(self):
+    def __repr__(self):  # pragma: no cover
         string_list = [
-            "'type': " + str(self.type),
+            "'kind': " + str(self.kind),
             "'lexeme': " + str(self.lexeme),
             "'literal': " + str(self.literal),
         ]
         return "{" + ", ".join(string_list) + "}"
 
-    def __str__(self):
+    def __str__(self):  # pragma: no cover
         string_list = [
-            "type= " + str(self.type),
+            "kind= " + str(self.kind),
             "lexeme= " + str(self.lexeme),
             "literal= " + str(self.literal),
         ]
